summaryrefslogtreecommitdiff
path: root/src/dev/x86/i82094aa.cc
diff options
context:
space:
mode:
authorSteve Reinhardt <stever@gmail.com>2013-07-11 21:56:50 -0500
committerSteve Reinhardt <stever@gmail.com>2013-07-11 21:56:50 -0500
commit502ad1e6757116867e0e0529c0c080320a2b440b (patch)
tree7f2f79fd913a23a4cfc6bdb9a3147551e6624c00 /src/dev/x86/i82094aa.cc
parent2737650a69f0c56d325c2d9cfd45eef099fbd581 (diff)
downloadgem5-502ad1e6757116867e0e0529c0c080320a2b440b.tar.xz
dev: consistently end device classes in 'Device'
PciDev and IntDev stuck out as the only device classes that ended in 'Dev' rather than 'Device'. This patch takes care of that inconsistency. Note that you may need to delete pre-existing files matching build/*/python/m5/internal/param_* as scons does not pick up indirect dependencies on imported python modules when generating params, and the PciDev -> PciDevice rename takes place in a file (dev/Device.py) that gets imported quite a bit. Committed by: Nilay Vaish <nilay@cs.wisc.edu>
Diffstat (limited to 'src/dev/x86/i82094aa.cc')
-rw-r--r--src/dev/x86/i82094aa.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/dev/x86/i82094aa.cc b/src/dev/x86/i82094aa.cc
index 1d3defa12..f547d7c1b 100644
--- a/src/dev/x86/i82094aa.cc
+++ b/src/dev/x86/i82094aa.cc
@@ -39,7 +39,7 @@
#include "sim/system.hh"
X86ISA::I82094AA::I82094AA(Params *p)
- : BasicPioDevice(p), IntDev(this, p->int_latency),
+ : BasicPioDevice(p), IntDevice(this, p->int_latency),
extIntPic(p->external_int_pic), lowestPriorityOffset(0)
{
// This assumes there's only one I/O APIC in the system and since the apic
@@ -65,10 +65,10 @@ X86ISA::I82094AA::init()
{
// The io apic must register its address ranges on both its pio port
// via the piodevice init() function and its int port that it inherited
// from IntDev. Note IntDev is not a SimObject itself.
BasicPioDevice::init();
- IntDev::init();
+ IntDevice::init();
}
BaseMasterPort &
@@ -65,10 +65,10 @@ X86ISA::I82094AA::init()
// The io apic must register its address ranges on both its pio port
// via the piodevice init() function and its int port that it inherited
- // from IntDev. Note IntDev is not a SimObject itself.
+ // from IntDevice. Note IntDevice is not a SimObject itself.
BasicPioDevice::init();